package io.swagger.petstore.test;

import io.swagger.client.ApiException;
import io.swagger.client.api.*;
import io.swagger.client.model.*;

import java.util.*;
import java.io.*;

import static org.junit.Assert.*;
import org.junit.*;

public class PetApiTest {
  PetApi api = null;

  @Before
  public void setup() {
    api = new PetApi();
  }

  @Test
  public void testCreateAndGetPet() throws Exception {
    Pet pet = createRandomPet();
    api.addPet(pet);

    Pet fetched = api.getPetById(pet.getId());
    assertNotNull(fetched);
    assertEquals(pet.getId(), fetched.getId());
    assertNotNull(fetched.getCategory());
    assertEquals(fetched.getCategory().getName(), pet.getCategory().getName());
  }

  @Test
  public void testUpdatePet() throws Exception {
    Pet pet = createRandomPet();
    pet.setName("programmer");

    api.updatePet(pet);

    Pet fetched = api.getPetById(pet.getId());
    assertNotNull(fetched);
    assertEquals(pet.getId(), fetched.getId());
    assertNotNull(fetched.getCategory());
    assertEquals(fetched.getCategory().getName(), pet.getCategory().getName());
  }

  @Test
  public void testFindPetsByStatus() throws Exception {
    Pet pet = createRandomPet();
    pet.setName("programmer");
    pet.setStatus(Pet.StatusEnum.available);

    api.updatePet(pet);

    List<Pet> pets = api.findPetsByStatus(Arrays.asList(new String[]{"available"}));
    assertNotNull(pets);

    boolean found = false;
    for(Pet fetched : pets) {
      if(fetched.getId().equals(pet.getId())) {
        found = true;
        break;
      }
    }

    assertTrue(found);
  }

  @Test
  public void testFindPetsByTags() throws Exception {
    Pet pet = createRandomPet();
    pet.setName("monster");
    pet.setStatus(Pet.StatusEnum.available);

    List<Tag> tags = new ArrayList<Tag>();
    Tag tag1 = new Tag();
    tag1.setName("friendly");
    tags.add(tag1);
    pet.setTags(tags);

    api.updatePet(pet);

    List<Pet> pets = api.findPetsByTags(Arrays.asList(new String[]{"friendly"}));
    assertNotNull(pets);

    boolean found = false;
    for(Pet fetched : pets) {
      if(fetched.getId().equals(pet.getId())) {
        found = true;
        break;
      }
    }
    assertTrue(found);
  }

  @Test
  public void testUpdatePetWithForm() throws Exception {
    Pet pet = createRandomPet();
    pet.setName("frank");
    api.addPet(pet);

    Pet fetched = api.getPetById(pet.getId());
    
    api.updatePetWithForm(String.valueOf(fetched.getId()), "furt", null);
    Pet updated = api.getPetById(fetched.getId());

    assertEquals(updated.getName(), "furt");
  }

  @Test
  public void testDeletePet() throws Exception {
    Pet pet = createRandomPet();
    api.addPet(pet);

    Pet fetched = api.getPetById(pet.getId());
    api.deletePet(null, fetched.getId());

    try {
      fetched = api.getPetById(fetched.getId());
      fail("expected an error");
    }
    catch (ApiException e) {
      assertEquals(404, e.getCode());
    }
  }

  @Test
  public void testUploadFile() throws Exception {
    Pet pet = createRandomPet();
    api.addPet(pet);

    File file = new File("hello.txt");
    BufferedWriter writer = new BufferedWriter(new FileWriter(file));
    writer.write("Hello world!");
    writer.close();

    api.uploadFile(pet.getId(), "a test file", new File(file.getAbsolutePath()));
  }

  private Pet createRandomPet() {
    Pet pet = new Pet();
    pet.setId(System.currentTimeMillis());
    pet.setName("gorilla");

    Category category = new Category();
    category.setName("really-happy");

    pet.setCategory(category);
    pet.setStatus(Pet.StatusEnum.available);
    List<String> photos = Arrays.asList(new String[]{"http://foo.bar.com/1", "http://foo.bar.com/2"});
    pet.setPhotoUrls(photos);

    return pet;
  }
}